/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2024 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "TaskStarter.h"

#include <U2Core/AppContext.h>

namespace U2 {

void TaskStarter::registerTask() {
    switch (condition) {
        case NoProject:
            if (AppContext::getProject() != nullptr) {
                delete t;
                t = nullptr;
                return;
            }
            break;

        case NoCondition:
        default:
            break;
    }

    if (t) {
        AppContext::getTaskScheduler()->registerTopLevelTask(t);
        t = nullptr;
    }

    deleteLater();
}

}  // namespace U2
